@@ -21,7 +21,6 @@ from kreuzberg.extraction import (
 
 
 def test_default_config_is_extraction_config() -> None:
-    """Test that DEFAULT_CONFIG is an ExtractionConfig instance."""
     assert isinstance(DEFAULT_CONFIG, ExtractionConfig)
     assert DEFAULT_CONFIG.use_cache is True
     assert DEFAULT_CONFIG.chunk_content is False
@@ -29,7 +28,6 @@ def test_default_config_is_extraction_config() -> None:
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_valid_mime_type() -> None:
-    """Test extract_bytes with valid content and mime type."""
     content = b"Hello, World!"
     mime_type = "text/plain"
 
@@ -44,11 +42,9 @@ async def test_extract_bytes_with_valid_mime_type() -> None:
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_unknown_mime_type() -> None:
-    """Test extract_bytes falls back to safe_decode for unknown mime types."""
     content = b"Unknown content type"
     mime_type = "application/unknown"
 
-    # Mock the validation to allow unknown mime type for testing
     with patch("kreuzberg.extraction.validate_mime_type", return_value=mime_type):
         result = await extract_bytes(content, mime_type)
 
@@ -57,7 +53,6 @@ async def test_extract_bytes_with_unknown_mime_type() -> None:
 
 
 def test_extract_bytes_sync_with_valid_mime_type() -> None:
-    """Test extract_bytes_sync with valid content and mime type."""
     content = b"Hello, World!"
     mime_type = "text/plain"
 
@@ -69,11 +64,9 @@ def test_extract_bytes_sync_with_valid_mime_type() -> None:
 
 
 def test_extract_bytes_sync_with_unknown_mime_type() -> None:
-    """Test extract_bytes_sync falls back to safe_decode for unknown mime types."""
     content = b"Unknown content type"
     mime_type = "application/unknown"
 
-    # Mock the validation to allow unknown mime type for testing
     with patch("kreuzberg.extraction.validate_mime_type", return_value=mime_type):
         result = extract_bytes_sync(content, mime_type)
 
@@ -83,7 +76,6 @@ def test_extract_bytes_sync_with_unknown_mime_type() -> None:
 
 @pytest.mark.anyio
 async def test_extract_file_nonexistent_file() -> None:
-    """Test extract_file raises ValidationError for nonexistent file."""
     nonexistent_path = "/nonexistent/file.txt"
 
     with pytest.raises(ValidationError, match="The file does not exist"):
@@ -91,7 +83,6 @@ async def test_extract_file_nonexistent_file() -> None:
 
 
 def test_extract_file_sync_nonexistent_file() -> None:
-    """Test extract_file_sync raises ValidationError for nonexistent file."""
     nonexistent_path = "/nonexistent/file.txt"
 
     with pytest.raises(ValidationError, match="The file does not exist"):
@@ -100,7 +91,6 @@ def test_extract_file_sync_nonexistent_file() -> None:
 
 @pytest.mark.anyio
 async def test_extract_file_with_cache_disabled(tmp_path: Path) -> None:
-    """Test extract_file with caching disabled."""
     test_file = tmp_path / "test.txt"
     test_file.write_text("Test content")
 
@@ -112,7 +102,6 @@ async def test_extract_file_with_cache_disabled(tmp_path: Path) -> None:
 
 
 def test_extract_file_sync_with_cache_disabled(tmp_path: Path) -> None:
-    """Test extract_file_sync with caching disabled."""
     test_file = tmp_path / "test.txt"
     test_file.write_text("Test content")
 
@@ -123,13 +112,42 @@ def test_extract_file_sync_with_cache_disabled(tmp_path: Path) -> None:
     assert result.mime_type == "text/plain"
 
 
+@pytest.mark.anyio
+async def test_extract_file_with_cache_hit(tmp_path: Path) -> None:
+    test_file = tmp_path / "test.txt"
+    test_file.write_text("Test content for cache")
+
+    config = ExtractionConfig(use_cache=True)
+
+    result1 = await extract_file(test_file, config=config)
+
+    result2 = await extract_file(test_file, config=config)
+
+    assert result1.content == result2.content
+    assert result1.content == "Test content for cache"
+    assert result1.mime_type == result2.mime_type == "text/plain"
+
+
+def test_extract_file_sync_with_cache_hit(tmp_path: Path) -> None:
+    test_file = tmp_path / "test.txt"
+    test_file.write_text("Test content for cache sync")
+
+    config = ExtractionConfig(use_cache=True)
+
+    result1 = extract_file_sync(test_file, config=config)
+
+    result2 = extract_file_sync(test_file, config=config)
+
+    assert result1.content == result2.content
+    assert result1.content == "Test content for cache sync"
+    assert result1.mime_type == result2.mime_type == "text/plain"
+
+
 @pytest.mark.anyio
 async def test_extract_file_with_unknown_mime_type(tmp_path: Path) -> None:
-    """Test extract_file with unknown mime type falls back to reading as text."""
     test_file = tmp_path / "test.unknown"
     test_file.write_text("Unknown file type content")
 
-    # Mock the validation to allow unknown mime type for testing
     with patch("kreuzberg.extraction.validate_mime_type", return_value="application/unknown"):
         result = await extract_file(test_file, mime_type="application/unknown")
 
@@ -138,11 +156,9 @@ async def test_extract_file_with_unknown_mime_type(tmp_path: Path) -> None:
 
 
 def test_extract_file_sync_with_unknown_mime_type(tmp_path: Path) -> None:
-    """Test extract_file_sync with unknown mime type falls back to reading as text."""
     test_file = tmp_path / "test.unknown"
     test_file.write_text("Unknown file type content")
 
-    # Mock the validation to allow unknown mime type for testing
     with patch("kreuzberg.extraction.validate_mime_type", return_value="application/unknown"):
         result = extract_file_sync(test_file, mime_type="application/unknown")
 
@@ -151,7 +167,6 @@ def test_extract_file_sync_with_unknown_mime_type(tmp_path: Path) -> None:
 
 
 def test_handle_chunk_content() -> None:
-    """Test _handle_chunk_content function."""
     content = "This is a long text that should be chunked into smaller pieces for processing."
     config = ExtractionConfig(max_chars=20, max_overlap=5)
 
@@ -162,12 +177,11 @@ def test_handle_chunk_content() -> None:
     )
 
     assert chunks is not None
-    assert len(chunks) > 1  # Should be chunked
+    assert len(chunks) > 1
 
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_chunking() -> None:
-    """Test extract_bytes with chunking enabled."""
     content = b"This is a long text that should be chunked into smaller pieces for processing."
     mime_type = "text/plain"
     config = ExtractionConfig(chunk_content=True, max_chars=20, max_overlap=5)
@@ -179,7 +193,6 @@ async def test_extract_bytes_with_chunking() -> None:
 
 
 def test_extract_bytes_sync_with_chunking() -> None:
-    """Test extract_bytes_sync with chunking enabled."""
     content = b"This is a long text that should be chunked into smaller pieces for processing."
     mime_type = "text/plain"
     config = ExtractionConfig(chunk_content=True, max_chars=20, max_overlap=5)
@@ -192,7 +205,6 @@ def test_extract_bytes_sync_with_chunking() -> None:
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_language_detection() -> None:
-    """Test extract_bytes with language detection enabled."""
     content = b"This is some English text for language detection."
     mime_type = "text/plain"
     config = ExtractionConfig(auto_detect_language=True, language_detection_config=LanguageDetectionConfig())
@@ -206,7 +218,6 @@ async def test_extract_bytes_with_language_detection() -> None:
 
 
 def test_extract_bytes_sync_with_language_detection() -> None:
-    """Test extract_bytes_sync with language detection enabled."""
     content = b"This is some English text for language detection."
     mime_type = "text/plain"
     config = ExtractionConfig(auto_detect_language=True, language_detection_config=LanguageDetectionConfig())
@@ -221,7 +232,6 @@ def test_extract_bytes_sync_with_language_detection() -> None:
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_entity_extraction_success() -> None:
-    """Test extract_bytes with successful entity extraction."""
     content = b"John works at Apple Inc. in California."
     mime_type = "text/plain"
     config = ExtractionConfig(extract_entities=True)
@@ -237,7 +247,6 @@ async def test_extract_bytes_with_entity_extraction_success() -> None:
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_entity_extraction_runtime_error() -> None:
-    """Test extract_bytes handles RuntimeError in entity extraction gracefully."""
     content = b"Some text for entity extraction."
     mime_type = "text/plain"
     config = ExtractionConfig(extract_entities=True)
@@ -251,7 +260,6 @@ async def test_extract_bytes_with_entity_extraction_runtime_error() -> None:
 
 
 def test_extract_bytes_sync_with_entity_extraction_runtime_error() -> None:
-    """Test extract_bytes_sync handles RuntimeError in entity extraction gracefully."""
     content = b"Some text for entity extraction."
     mime_type = "text/plain"
     config = ExtractionConfig(extract_entities=True)
@@ -266,7 +274,6 @@ def test_extract_bytes_sync_with_entity_extraction_runtime_error() -> None:
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_keyword_extraction_success() -> None:
-    """Test extract_bytes with successful keyword extraction."""
     content = b"Machine learning and artificial intelligence are important technologies."
     mime_type = "text/plain"
     config = ExtractionConfig(extract_keywords=True, keyword_count=5)
@@ -282,7 +289,6 @@ async def test_extract_bytes_with_keyword_extraction_success() -> None:
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_keyword_extraction_runtime_error() -> None:
-    """Test extract_bytes handles RuntimeError in keyword extraction gracefully."""
     content = b"Some text for keyword extraction."
     mime_type = "text/plain"
     config = ExtractionConfig(extract_keywords=True)
@@ -296,7 +302,6 @@ async def test_extract_bytes_with_keyword_extraction_runtime_error() -> None:
 
 
 def test_extract_bytes_sync_with_keyword_extraction_runtime_error() -> None:
-    """Test extract_bytes_sync handles RuntimeError in keyword extraction gracefully."""
     content = b"Some text for keyword extraction."
     mime_type = "text/plain"
     config = ExtractionConfig(extract_keywords=True)
@@ -311,7 +316,6 @@ def test_extract_bytes_sync_with_keyword_extraction_runtime_error() -> None:
 
 @pytest.mark.anyio
 async def test_extract_bytes_with_auto_detect_document_type() -> None:
-    """Test extract_bytes with auto document type detection enabled."""
     content = b"This is a document with specific formatting."
     mime_type = "text/plain"
     config = ExtractionConfig(auto_detect_document_type=True)
@@ -332,7 +336,6 @@ async def test_extract_bytes_with_auto_detect_document_type() -> None:
 
 @pytest.mark.anyio
 async def test_validate_and_post_process_async_with_validators() -> None:
-    """Test _validate_and_post_process_async with custom validators."""
     result = ExtractionResult(content="Test content", mime_type="text/plain", metadata={}, chunks=[])
 
     async_validator = AsyncMock()
@@ -349,7 +352,6 @@ async def test_validate_and_post_process_async_with_validators() -> None:
 
 @pytest.mark.anyio
 async def test_validate_and_post_process_async_with_post_processors() -> None:
-    """Test _validate_and_post_process_async with post processing hooks."""
     result = ExtractionResult(content="Test content", mime_type="text/plain", metadata={}, chunks=[])
 
     modified_result = ExtractionResult(
@@ -364,17 +366,14 @@ async def test_validate_and_post_process_async_with_post_processors() -> None:
 
     config = ExtractionConfig(post_processing_hooks=[async_processor, sync_processor])
 
-    # Mock _validate_and_post_process_helper to return the original result
     with patch("kreuzberg.extraction._validate_and_post_process_helper", return_value=result):
         processed_result = await _validate_and_post_process_async(result, config)
 
-    # Only the last processor's result should be returned
     assert processed_result.content == "Modified content"
     assert processed_result.metadata.get("processed") is True
 
 
 def test_validate_and_post_process_sync_with_validators() -> None:
-    """Test _validate_and_post_process_sync with custom validators."""
     result = ExtractionResult(content="Test content", mime_type="text/plain", metadata={}, chunks=[])
 
     validator = Mock()
@@ -387,7 +386,6 @@ def test_validate_and_post_process_sync_with_validators() -> None:
 
 
 def test_validate_and_post_process_sync_with_post_processors() -> None:
-    """Test _validate_and_post_process_sync with post processing hooks."""
     result = ExtractionResult(content="Test content", mime_type="text/plain", metadata={}, chunks=[])
 
     modified_result = ExtractionResult(
@@ -400,7 +398,6 @@ def test_validate_and_post_process_sync_with_post_processors() -> None:
     processor = Mock(return_value=modified_result)
     config = ExtractionConfig(post_processing_hooks=[processor])
 
-    # Mock _validate_and_post_process_helper to return the original result
     with patch("kreuzberg.extraction._validate_and_post_process_helper", return_value=result):
         processed_result = _validate_and_post_process_sync(result, config)
 
@@ -410,7 +407,6 @@ def test_validate_and_post_process_sync_with_post_processors() -> None:
 
 
 def test_validate_and_post_process_helper_with_all_features() -> None:
-    """Test _validate_and_post_process_helper with all features enabled."""
     result = ExtractionResult(
         content="This is test content for processing.", mime_type="text/plain", metadata={}, chunks=[]
     )
@@ -433,7 +429,6 @@ def test_validate_and_post_process_helper_with_all_features() -> None:
         patch("kreuzberg.extraction.detect_languages") as mock_languages,
         patch("kreuzberg.extraction.auto_detect_document_type") as mock_doc_type,
     ):
-        # Setup mocks
         mock_chunker_instance = Mock()
         mock_chunker_instance.chunks.return_value = ["chunk1", "chunk2"]
         mock_chunker.return_value = mock_chunker_instance
@@ -441,7 +436,7 @@ def test_validate_and_post_process_helper_with_all_features() -> None:
         mock_entities.return_value = [{"text": "test", "label": "MISC"}]
         mock_keywords.return_value = ["test", "content", "processing"]
         mock_languages.return_value = ["en"]
-        mock_doc_type.return_value = result  # Return unchanged
+        mock_doc_type.return_value = result
 
         processed_result = _validate_and_post_process_helper(result, config, Path("/test/path.txt"))
 
@@ -455,3 +450,45 @@ def test_validate_and_post_process_helper_with_all_features() -> None:
     mock_keywords.assert_called_once_with(result.content, keyword_count=3)
     mock_languages.assert_called_once()
     mock_doc_type.assert_called_once_with(result, config, file_path=Path("/test/path.txt"))
+
+
+@pytest.mark.anyio
+async def test_extract_bytes_with_html_extractor() -> None:
+    content = b"<html><body><h1>Test HTML</h1></body></html>"
+    mime_type = "text/html"
+
+    result = await extract_bytes(content, mime_type)
+
+    assert "Test HTML" in result.content
+    assert result.mime_type == "text/markdown"
+
+
+def test_extract_bytes_sync_with_html_extractor() -> None:
+    content = b"<html><body><h1>Test HTML</h1></body></html>"
+    mime_type = "text/html"
+
+    result = extract_bytes_sync(content, mime_type)
+
+    assert "Test HTML" in result.content
+    assert result.mime_type == "text/markdown"
+
+
+@pytest.mark.anyio
+async def test_extract_file_with_html_extractor(tmp_path: Path) -> None:
+    test_file = tmp_path / "test.html"
+    test_file.write_text("<html><body><h1>Test HTML File</h1></body></html>")
+
+    result = await extract_file(test_file, mime_type="text/html")
+
+    assert "Test HTML File" in result.content
+    assert result.mime_type == "text/markdown"
+
+
+def test_extract_file_sync_with_html_extractor(tmp_path: Path) -> None:
+    test_file = tmp_path / "test.html"
+    test_file.write_text("<html><body><h1>Test HTML File</h1></body></html>")
+
+    result = extract_file_sync(test_file, mime_type="text/html")
+
+    assert "Test HTML File" in result.content
+    assert result.mime_type == "text/markdown"
