@@ -1,5 +1,3 @@
-"""Tests for error handling utilities."""
-
 from __future__ import annotations
 
 from datetime import datetime
@@ -23,14 +21,12 @@ if TYPE_CHECKING:
 
 @pytest.fixture
 def test_file(tmp_path: Path) -> Path:
-    """Create a test file."""
     file_path = tmp_path / "test.txt"
     file_path.write_text("test content")
     return file_path
 
 
 def test_create_error_context_basic() -> None:
-    """Test basic error context creation."""
     context = create_error_context(operation="test_op")
 
     assert context["operation"] == "test_op"
@@ -39,7 +35,6 @@ def test_create_error_context_basic() -> None:
 
 
 def test_create_error_context_with_file(test_file: Path) -> None:
-    """Test error context with file information."""
     context = create_error_context(
         operation="file_read",
         file_path=test_file,
@@ -53,7 +48,6 @@ def test_create_error_context_with_file(test_file: Path) -> None:
 
 
 def test_create_error_context_with_nonexistent_file() -> None:
-    """Test error context with non-existent file."""
     context = create_error_context(
         operation="file_read",
         file_path="/nonexistent/file.txt",
@@ -65,7 +59,6 @@ def test_create_error_context_with_nonexistent_file() -> None:
 
 
 def test_create_error_context_with_error() -> None:
-    """Test error context with exception."""
     try:
         raise ValueError("Test error message")
     except ValueError as e:
@@ -82,7 +75,6 @@ def test_create_error_context_with_error() -> None:
 
 
 def test_create_error_context_with_extra() -> None:
-    """Test error context with extra fields."""
     context = create_error_context(
         operation="test_op",
         custom_field="custom_value",
@@ -94,7 +86,6 @@ def test_create_error_context_with_extra() -> None:
 
 
 def test_create_error_context_with_resource_error() -> None:
-    """Test error context with resource-related error includes system info."""
     try:
         raise MemoryError("Out of memory")
     except MemoryError as e:
@@ -112,7 +103,6 @@ def test_create_error_context_with_resource_error() -> None:
 
 
 def test_create_error_context_system_info_error() -> None:
-    """Test error context when system info collection fails."""
     with patch("psutil.virtual_memory", side_effect=Exception("psutil error")):
         try:
             raise RuntimeError("Resource exhausted")
@@ -127,7 +117,6 @@ def test_create_error_context_system_info_error() -> None:
 
 
 def test_create_error_context_with_path_string() -> None:
-    """Test error context with string path."""
     import os
 
     test_path = "/some/path/file.txt"
@@ -142,8 +131,6 @@ def test_create_error_context_with_path_string() -> None:
 
 
 def test_is_transient_error() -> None:
-    """Test transient error detection."""
-
     assert is_transient_error(OSError("Resource temporarily unavailable"))
     assert is_transient_error(PermissionError("Access denied"))
     assert is_transient_error(TimeoutError("Operation timed out"))
@@ -161,8 +148,6 @@ def test_is_transient_error() -> None:
 
 
 def test_is_resource_error() -> None:
-    """Test resource error detection."""
-
     assert is_resource_error(MemoryError("Out of memory"))
     assert is_resource_error(OSError("Cannot allocate memory"))
     assert is_resource_error(OSError("Too many open files"))
@@ -179,8 +164,6 @@ def test_is_resource_error() -> None:
 
 
 def test_should_retry() -> None:
-    """Test retry logic."""
-
     error = TimeoutError("Request timed out")
     assert should_retry(error, attempt=1, max_attempts=3)
     assert should_retry(error, attempt=2, max_attempts=3)
@@ -194,7 +177,6 @@ def test_should_retry() -> None:
 
 
 def test_should_retry_max_attempts() -> None:
-    """Test retry logic respects max attempts."""
     error = TimeoutError("Timeout")
 
     assert should_retry(error, attempt=1)
@@ -205,104 +187,157 @@ def test_should_retry_max_attempts() -> None:
     assert not should_retry(error, attempt=5, max_attempts=5)
 
 
-class TestBatchExtractionResult:
-    """Tests for BatchExtractionResult class."""
+def test_batch_extraction_result_init() -> None:
+    result = BatchExtractionResult()
 
-    def test_init(self) -> None:
-        """Test initialization."""
-        result = BatchExtractionResult()
+    assert result.successful == []
+    assert result.failed == []
+    assert result.total_count == 0
+    assert result.success_count == 0
+    assert result.failure_count == 0
+    assert result.success_rate == 0.0
 
-        assert result.successful == []
-        assert result.failed == []
-        assert result.total_count == 0
-        assert result.success_count == 0
-        assert result.failure_count == 0
-        assert result.success_rate == 0.0
 
-    def test_add_success(self) -> None:
-        """Test adding successful results."""
-        result = BatchExtractionResult()
-        result.total_count = 3
+def test_batch_extraction_result_add_success() -> None:
+    result = BatchExtractionResult()
+    result.total_count = 3
 
-        result.add_success(0, "Result 1")
-        result.add_success(2, "Result 3")
+    result.add_success(0, "Result 1")
+    result.add_success(2, "Result 3")
 
-        assert result.success_count == 2
-        assert result.successful == [(0, "Result 1"), (2, "Result 3")]
+    assert result.success_count == 2
+    assert result.successful == [(0, "Result 1"), (2, "Result 3")]
 
-    def test_add_failure(self) -> None:
-        """Test adding failed results."""
-        result = BatchExtractionResult()
-        result.total_count = 3
 
-        error = ValueError("Test error")
-        context = {"file": "test.txt"}
+def test_batch_extraction_result_add_failure() -> None:
+    result = BatchExtractionResult()
+    result.total_count = 3
 
-        result.add_failure(1, error, context)
+    error = ValueError("Test error")
+    context = {"file": "test.txt"}
 
-        assert result.failure_count == 1
-        assert len(result.failed) == 1
+    result.add_failure(1, error, context)
 
-        index, error_info = result.failed[0]
-        assert index == 1
-        assert error_info["error"]["type"] == "ValueError"
-        assert error_info["error"]["message"] == "Test error"
-        assert error_info["context"] == context
+    assert result.failure_count == 1
+    assert len(result.failed) == 1
 
-    def test_success_rate(self) -> None:
-        """Test success rate calculation."""
-        result = BatchExtractionResult()
-        result.total_count = 4
+    index, error_info = result.failed[0]
+    assert index == 1
+    assert error_info["error"]["type"] == "ValueError"
+    assert error_info["error"]["message"] == "Test error"
+    assert error_info["context"] == context
 
-        result.add_success(0, "R1")
-        result.add_success(1, "R2")
-        result.add_success(3, "R4")
-        result.add_failure(2, ValueError("Error"), {})
 
-        assert result.success_rate == 75.0
+def test_batch_extraction_result_success_rate() -> None:
+    result = BatchExtractionResult()
+    result.total_count = 4
 
-    def test_get_ordered_results(self) -> None:
-        """Test getting results in original order."""
-        result = BatchExtractionResult()
-        result.total_count = 5
+    result.add_success(0, "R1")
+    result.add_success(1, "R2")
+    result.add_success(3, "R4")
+    result.add_failure(2, ValueError("Error"), {})
 
-        result.add_success(0, "First")
-        result.add_success(2, "Third")
-        result.add_success(4, "Fifth")
-        result.add_failure(1, ValueError("E1"), {})
-        result.add_failure(3, RuntimeError("E2"), {})
+    assert result.success_rate == 75.0
 
-        ordered = result.get_ordered_results()
 
-        assert ordered == ["First", None, "Third", None, "Fifth"]
+def test_batch_extraction_result_get_ordered_results() -> None:
+    result = BatchExtractionResult()
+    result.total_count = 5
 
-    def test_get_summary(self) -> None:
-        """Test getting operation summary."""
-        result = BatchExtractionResult()
-        result.total_count = 3
+    result.add_success(0, "First")
+    result.add_success(2, "Third")
+    result.add_success(4, "Fifth")
+    result.add_failure(1, ValueError("E1"), {})
+    result.add_failure(3, RuntimeError("E2"), {})
 
-        result.add_success(0, "OK1")
-        result.add_success(2, "OK2")
-        result.add_failure(1, ValueError("Bad value"), {"file": "test.txt"})
+    ordered = result.get_ordered_results()
 
-        summary = result.get_summary()
+    assert ordered == ["First", None, "Third", None, "Fifth"]
 
-        assert summary["total"] == 3
-        assert summary["successful"] == 2
-        assert summary["failed"] == 1
-        assert summary["success_rate"] == "66.7%"
 
-        assert len(summary["failures"]) == 1
-        failure = summary["failures"][0]
-        assert failure["index"] == 1
-        assert failure["error"] == "ValueError"
-        assert failure["message"] == "Bad value"
+def test_batch_extraction_result_get_summary() -> None:
+    result = BatchExtractionResult()
+    result.total_count = 3
 
-    def test_empty_batch_success_rate(self) -> None:
-        """Test success rate for empty batch."""
-        result = BatchExtractionResult()
+    result.add_success(0, "OK1")
+    result.add_success(2, "OK2")
+    result.add_failure(1, ValueError("Bad value"), {"file": "test.txt"})
 
-        assert result.success_rate == 0.0
+    summary = result.get_summary()
 
-        summary = result.get_summary()
-        assert summary["success_rate"] == "0.0%"
+    assert summary["total"] == 3
+    assert summary["successful"] == 2
+    assert summary["failed"] == 1
+    assert summary["success_rate"] == "66.7%"
+
+    assert len(summary["failures"]) == 1
+    failure = summary["failures"][0]
+    assert failure["index"] == 1
+    assert failure["error"] == "ValueError"
+    assert failure["message"] == "Bad value"
+
+
+def test_batch_extraction_result_empty_batch_success_rate() -> None:
+    result = BatchExtractionResult()
+
+    assert result.success_rate == 0.0
+
+    summary = result.get_summary()
+    assert summary["success_rate"] == "0.0%"
+
+
+def test_batch_extraction_result_properties() -> None:
+    result = BatchExtractionResult()
+    result.total_count = 5
+
+    result.add_success(0, "result1")
+    result.add_success(2, "result3")
+    result.add_failure(1, ValueError("error1"), {})
+    result.add_failure(4, OSError("error2"), {})
+
+    assert result.success_count == 2
+    assert result.failure_count == 2
+    assert result.success_rate == 40.0
+
+
+def test_batch_extraction_result_success_rate_zero_total() -> None:
+    result = BatchExtractionResult()
+    assert result.success_rate == 0.0
+
+
+def test_is_transient_error_with_patterns() -> None:
+    assert is_transient_error(Exception("temporary failure")) is True
+    assert is_transient_error(Exception("file is locked")) is True
+    assert is_transient_error(Exception("resource in use")) is True
+    assert is_transient_error(Exception("access denied")) is True
+    assert is_transient_error(Exception("permission denied")) is True
+    assert is_transient_error(Exception("connection timeout")) is True
+    assert is_transient_error(Exception("network error")) is True
+    assert is_transient_error(Exception("too many open files")) is True
+    assert is_transient_error(Exception("cannot allocate memory")) is True
+    assert is_transient_error(Exception("resource temporarily unavailable")) is True
+    assert is_transient_error(Exception("broken pipe")) is True
+    assert is_transient_error(Exception("subprocess failed")) is True
+    assert is_transient_error(Exception("signal interrupted")) is True
+
+
+def test_is_transient_error_non_transient() -> None:
+    assert is_transient_error(ValueError("invalid value")) is False
+    assert is_transient_error(TypeError("type error")) is False
+    assert is_transient_error(KeyError("key not found")) is False
+    assert is_transient_error(Exception("some other error")) is False
+
+
+def test_should_retry_validation_error() -> None:
+    validation_error = ValidationError("invalid input")
+
+    assert should_retry(validation_error, attempt=1, max_attempts=3) is False
+    assert should_retry(validation_error, attempt=1, max_attempts=10) is False
+
+
+def test_should_retry_transient_vs_non_transient() -> None:
+    transient_error = OSError("temporary failure")
+    non_transient_error = ValueError("invalid value")
+
+    assert should_retry(transient_error, attempt=1, max_attempts=3) is True
+    assert should_retry(non_transient_error, attempt=1, max_attempts=3) is False
